--- as_version.cpp 2002/12/17 16:59:06 1.9
+++ as_version.cpp 2002/12/18 15:47:47 1.10
@@ -1,5 +1,5 @@
/*
** as_version.cpp -- Version Information for OSSP asgui (syntax: C/C++)
** [automatically generated and maintained by GNU shtool]
*/
@@ -8,7 +8,7 @@
#ifndef _AS_VERSION_CPP_
#define _AS_VERSION_CPP_
-#define ASGUI_VERSION 0x005207
+#define ASGUI_VERSION 0x005208
typedef struct {
const int v_hex;
@@ -32,14 +32,14 @@
#undef _AS_VERSION_CPP_AS_HEADER_
asgui_version_t asgui_version = {
- 0x005207,
- "0.5.7",
- "0.5.7 (17-Dec-2002)",
- "This is OSSP asgui, Version 0.5.7 (17-Dec-2002)",
- "OSSP asgui 0.5.7 (17-Dec-2002)",
- "OSSP asgui/0.5.7",
- "@(#)OSSP asgui 0.5.7 (17-Dec-2002)",
- "$Id: as_version.cpp,v 1.9 2002/12/17 16:59:06 ms Exp $"
+ 0x005208,
+ "0.5.8",
+ "0.5.8 (18-Dec-2002)",
+ "This is OSSP as-gui, Version 0.5.8 (18-Dec-2002)",
+ "OSSP as-gui 0.5.8 (18-Dec-2002)",
+ "OSSP as-gui/0.5.8",
+ "@(#)OSSP as-gui 0.5.8 (18-Dec-2002)",
+ "$Id: as_version.cpp,v 1.10 2002/12/18 15:47:47 ms Exp $"
};
#endif /* _AS_VERSION_CPP_AS_HEADER_ */
|
@@ -1,5 +1,5 @@
/*
-** as_version.cpp -- Version Information for OSSP asgui (syntax: C/C++)
+** as_version.cpp -- Version Information for OSSP as-gui (syntax: C/C++)
** [automatically generated and maintained by GNU shtool]
*/